<?php
namespace Forgood;

/**
 * Class Plugin
 * Main Plugin class
 * @since 1.2.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
		 * _widget_categories()
		 * @since 1.0.0
		 * */
		public function _widget_categories($elements_manager){
			$elements_manager->add_category(
				'forgood_widgets',
				[
					'title' => __( 'Forgood Widgets', 'forgood' ),
					'icon' => 'fa fa-plug',
				]
			);
		}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		wp_register_script( 'forgood', plugins_url( '/assets/js/hello-world.js', __FILE__ ), [ 'jquery' ], false, true );
	}

	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/fgood-section-title.php' );
		require_once( __DIR__ . '/widgets/fgood-banner.php' );
		require_once( __DIR__ . '/widgets/fgood-intro.php' );
		require_once( __DIR__ . '/widgets/fgood-causes.php' );
		require_once( __DIR__ . '/widgets/fgood-team.php' );
		require_once( __DIR__ . '/widgets/fgood-event.php' );
		require_once( __DIR__ . '/widgets/fgood-blog.php' );
		require_once( __DIR__ . '/widgets/fgood-testimonial.php' );
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Fgood_Section_Title() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Fgood_Banner() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Fgood_Causes() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Fgood_Blog() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\Fgood_Testimonial() );
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {
		add_action( 'elementor/elements/categories_registered', array($this,'_widget_categories') );

		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();


//fgood_include
include 'fgood_include.php';